@@ -1573,6 +1573,8 @@ class Update(MethodsInterface):
             self.clVars.Set('update.cl_update_binhost_recheck_set', Variable.On)
             self.clVars.Set('cl_update_package_cache_set', Variable.Off, force=True)
             raise
+        self.clVars.Write('cl_update_binhost', url_binhost.split('/grp/')[0])
+        self.clVars.Set('update.cl_update_binhost', url_binhost.split('/grp/')[0])
         return True
 
     class Reason():
@@ -1622,7 +1624,8 @@ class Update(MethodsInterface):
             dv.Write('cl_update_binhost_set', "off")
             dv.Set('cl_update_binhost_set', 'off')
         if (not dv.Get('update.cl_update_binhost_choice') and not dv.GetBool('update.cl_update_binhost_set')) \
-                or dv.Get('update.cl_update_binhost_choice') == 'auto':
+                or dv.Get('update.cl_update_binhost_choice') == 'auto' \
+                or (dv.Get('update.cl_update_binhost') and not dv.GetBool('update.cl_update_binhost_set')):
             if dv.Get('cl_update_binhost_stable_opt_set'):
                 binhost_list = dv.Get('cl_update_binhost_list')
             else:
@@ -1846,7 +1849,7 @@ class Update(MethodsInterface):
         self.clVars.Set('update.cl_update_binhost_data',
             retval or Variable.EmptyTable, force=True)
         if not ignore_level:
-            best_binhost_level = int(self.clVars.Get("update.cl_update_binhost_level")[0]) or None
+            best_binhost_level = int(self.clVars.Get("update.cl_update_binhost_level")[0])
             #int(sorted(self.clVars.Get("update.cl_update_binhost_level"), key=int)[-1])
             # int(self.clVars.Get("update.cl_update_binhost_level")[0])
             
