@@ -207,8 +207,6 @@ class VariableClUpdateRepHostingChoice(Variable):
         self.help = (_("Hosting to download repository from"))
 
     def choice(self):
-        a = [x[1] for x in self.Get('cl_update_inner_rep_list')]
-        b = self.Get('cl_update_inner_rep_list')
         return [x[1] for x in self.Get('cl_update_inner_rep_list')] or ['Default']
 
 
@@ -1841,8 +1839,12 @@ class VariableClUpdatePortageBinhost(ReadonlyVariable):
     """
     Прописываемый в /etc/portage/make.conf/binhost репозиторий
     """
-    value_format = "{update.cl_update_binhost}/grp/{os_arch_machine}"
+    #value_format = "{update.cl_update_binhost}/grp/{os_arch_machine}"
 
+    def get(self):
+        if self.Get('update.cl_update_binhost_choice'):
+            return f"{self.Get('update.cl_update_binhost_choice')}/grp/{self.Get('os_arch_machine')}"
+        return f"{self.Get('update.cl_update_binhost')}/grp/{self.Get('os_arch_machine')}"
 
 class VariableClUpdatePackageCache(ReadonlyVariable):
     """
